@@ -646,7 +646,8 @@ class Tether(Evaluator):
         positionZ = data[:, [3]]
         calibration = self.calibration
 
-        dispXYZ = displacementXYZ(calibration, psdXYZ, positionZ,
+        dispXYZ = displacementXYZ(psdXYZ, calibration=calibration,
+                                  positionZ=positionZ,
                                   dXYZ_factors=dXYZ_factors)
         return dispXYZ
 
@@ -660,7 +661,7 @@ class Tether(Evaluator):
         positionZ = data[:, [3]]
         calibration = self.calibration
 
-        fXYZ = forceXYZ(calibration, psdXYZ, positionZ,
+        fXYZ = forceXYZ(psdXYZ, calibration=calibration, positionZ=positionZ,
                         dXYZ_factors=dXYZ_factors, fXYZ_factors=fXYZ_factors)
         return fXYZ
 
@@ -694,7 +695,7 @@ class Tether(Evaluator):
         if twoD:
             psdXYZ[:, Z] = 0.0
 
-        fXYZ = forceXYZ(calibration, psdXYZ, positionZ,
+        fXYZ = forceXYZ(psdXYZ, calibration=calibration, positionZ=positionZ,
                         dXYZ_factors=dXYZ_factors, fXYZ_factors=fXYZ_factors)
         f = force(fXYZ, positionXY, posmin=posmin)
         return f
@@ -709,7 +710,8 @@ class Tether(Evaluator):
         positionXYZ = data[:, 3:6]
         calibration = self.calibration
 
-        distXYZ = distanceXYZ(calibration, psdXYZ, positionXYZ,
+        distXYZ = distanceXYZ(positionXYZ, psdXYZ=psdXYZ,
+                              calibration=calibration,
                               dXYZ_factors=dXYZ_factors)
         return distXYZ
 
@@ -741,7 +743,8 @@ class Tether(Evaluator):
         if twoD:
             psdXYZ[:, Z] = 0.0
 
-        distXYZ = distanceXYZ(calibration, psdXYZ, positionXYZ,
+        distXYZ = distanceXYZ(positionXYZ, psdXYZ=psdXYZ,
+                              calibration=calibration,
                               dXYZ_factors=dXYZ_factors)
         dist = distance(distXYZ, positionXY, posmin=posmin)
         return dist
@@ -842,14 +845,16 @@ class Tether(Evaluator):
         # 2D or 3D calculation of the distance in Z
         if twoD:
             psdXYZ[:, Z] = 0.0
-        displXYZ = displacementXYZ(calibration, psdXYZ, positionZ=positionZ,
-                                   dXYZ_factors=dXYZ_factors)
-        distXYZ = distanceXYZ(calibration, psdXYZ, positionXYZ,
-                              displXYZ=displXYZ, dXYZ_factors=dXYZ_factors)
+        dispXYZ = displacementXYZ(psdXYZ, calibration=calibration,
+                                  positionZ=positionZ,
+                                  dXYZ_factors=dXYZ_factors)
+        distXYZ = distanceXYZ(positionXYZ, dispXYZ=dispXYZ,
+                              calibration=calibration,
+                              dXYZ_factors=dXYZ_factors)
         dist = distance(distXYZ, positionXY, posmin=posmin)
         e = extension(dist, calibration.radius)
 
-        fXYZ = forceXYZ(calibration, psdXYZ, positionZ,
+        fXYZ = forceXYZ(psdXYZ, calibration=calibration, positionZ=positionZ,
                         dXYZ_factors=dXYZ_factors, fXYZ_factors=fXYZ_factors)
         f = force(fXYZ, positionXY, posmin=posmin)
 
@@ -988,12 +993,16 @@ def print_info(tether, i=0):
                                     * tether.calibration.focalshift))
 
 
-def displacementXYZ(calibration, psdXYZ, positionZ=0.0, dXYZ_factors=None):
+def displacementXYZ(psdXYZ, calibration=None, positionZ=0.0, beta=None,
+                    dXYZ_factors=None):
     """
     Displacement in m with height dependent calibration factors for X, Y
     and Z.
     """
-    dispXYZ = calibration.displacement(psdXYZ, positionZ=positionZ)
+    if calibration is not None:
+        dispXYZ = calibration.displacement(psdXYZ, positionZ=positionZ)
+    else:
+        dispXYZ = psdXYZ * beta
 
     # Optionally use correctur factors for the calculated displacement
     dXYZ_factors = 1 if dXYZ_factors is None else dXYZ_factors
@@ -1003,14 +1012,20 @@ def displacementXYZ(calibration, psdXYZ, positionZ=0.0, dXYZ_factors=None):
     return dispXYZ
 
 
-def forceXYZ(calibration, psdXYZ, positionZ, dXYZ_factors=None,
-             fXYZ_factors=None):
+def forceXYZ(psdXYZ=None, dispXYZ=None, calibration=None, positionZ=0.0,
+             beta=None, kappa=None, dXYZ_factors=None, fXYZ_factors=None):
     """
     Force acting on the bead
     """
-    dispXYZ = displacementXYZ(calibration, psdXYZ, positionZ=positionZ,
-                              dXYZ_factors=dXYZ_factors)
-    fXYZ = calibration.force(dispXYZ, positionZ=positionZ)
+    if dispXYZ is None:
+        dispXYZ = displacementXYZ(psdXYZ, calibration=calibration,
+                                  positionZ=positionZ, beta=beta,
+                                  dXYZ_factors=dXYZ_factors)
+
+    if calibration is not None:
+        fXYZ = calibration.force(dispXYZ, positionZ=positionZ)
+    else:
+        fXYZ = dispXYZ * kappa
 
     # Optionally use correctur factors for the calculated force
     fXYZ_factors = 1 if fXYZ_factors is None else fXYZ_factors
@@ -1067,8 +1082,9 @@ def force(forceXYZ, positionXY, posmin=10e-9, sign_axes=None):
     return force
 
 
-def distanceXYZ(calibration, psdXYZ, positionXYZ, displXYZ=None, radius=None,
-                focalshift=None, clip_Z=True, dXYZ_factors=None):
+def distanceXYZ(positionXYZ, psdXYZ=None, dispXYZ=None, calibration=None,
+                beta=None, radius=None, focalshift=None, clip_Z=True,
+                dXYZ_factors=None):
     """
     Distance of the attachment point to the bead center as a 3D vector.
     positionXYZ, displacementXYZ and radius need to have the same unit.
@@ -1099,16 +1115,17 @@ def distanceXYZ(calibration, psdXYZ, positionXYZ, displXYZ=None, radius=None,
         radius = calibration.radius
     positionZ = positionXYZ[:,2]
 
-    if displXYZ is None:
-        displXYZ = displacementXYZ(calibration, psdXYZ, positionZ=positionZ,
-                                   dXYZ_factors=dXYZ_factors)
+    if dispXYZ is None:
+        dispXYZ = displacementXYZ(psdXYZ, calibration=calibration,
+                                  positionZ=positionZ, beta=beta,
+                                  dXYZ_factors=dXYZ_factors)
 
     # distance, point of attachment of DNA
     # displacement, displacement of bead out of trap center radius
     distanceXYZ = positionXYZ.copy()
     # distance from attachment point to center of bead
     # attachmentXY - displacementXY
-    distanceXYZ[:, 0:2] -= displXYZ[:, 0:2]
+    distanceXYZ[:, 0:2] -= dispXYZ[:, 0:2]
     # Direction of distance vector is from attachment point to the bead center
     distanceXYZ[:, 0:2] *= -1
 
@@ -1122,11 +1139,11 @@ def distanceXYZ(calibration, psdXYZ, positionXYZ, displXYZ=None, radius=None,
     distanceXYZ[idx_free, 2] = (- positionXYZ[idx_free, 2] * focalshift
                                 + radius
                                 # distanceZ + radius + displacementZ
-                                + displXYZ[idx_free, 2])
+                                + dispXYZ[idx_free, 2])
     distanceXYZ[idx_touch, 2] = (- positionXYZ[idx_touch, 2]
                                  + radius
                                  # distanceZ + radius + displacementZ
-                                 + displXYZ[idx_touch, 2])
+                                 + dispXYZ[idx_touch, 2])
 
     if clip_Z:
         distanceXYZ[:, 2] = distanceXYZ[:, 2].clip(min=radius)
