@@ -146,10 +146,14 @@ WIDGET_CLASS = {
     None: widgets.Button,
     bool: widgets.Checkbox,
     float: widgets.FloatText,
-    int: widgets.FloatText,
+    int: widgets.IntText,
     list: widgets.SelectMultiple,
     tuple: widgets.SelectMultiple
 }
+WIDGET_CLASS_BOUNDED = {
+    float: widgets.BoundedFloatText,
+    int: widgets.BoundedIntText
+}
 
 
 class InteractiveAttributes(persistent.Persistent):
@@ -195,7 +199,7 @@ class InteractiveAttributes(persistent.Persistent):
         """
         # create and register a widget
         widget = self._create_widget(key, value=value, description=description,
-                                     options=options)
+                                     options=options, **kwargs)
         self._widgets[key] = widget
 
         # Register callback functions to be called upon widget value change
@@ -208,19 +212,20 @@ class InteractiveAttributes(persistent.Persistent):
         # inform ZODB of change
         self._p_changed = True
 
-    def _create_widget(self, key, value=None, description=None, options=None):
+    def _create_widget(self, key, value=None, description=None, options=None,
+                       **kwargs):
         # create widget according to the type of value
         try:
-            if value is None:
-                value_type = None
-            else:
-                value_type = type(value)
+            value_type = value if value is None else type(value)
             if isinstance(value, collections.Iterable) \
                 and not isinstance(options, collections.Iterable):
                     options = value
-            widget_class = WIDGET_CLASS[value_type]
+            if 'min' in kwargs or 'max' in kwargs:
+                widget_class = WIDGET_CLASS_BOUNDED[value_type]
+            else:
+                widget_class = WIDGET_CLASS[value_type]
             widget = widget_class(description=description, value=value,
-                                  options=options)
+                                  options=options, **kwargs)
 
             # register _widget_callback() to be called upon change of widget
             # value
@@ -326,9 +331,9 @@ class InteractiveAttributes(persistent.Persistent):
     def __getstate__(self):
         """Return state values to be pickled."""
         # To circumvent: TypeError: can't pickle instancemethod objects
-        # __getstate__ should replace instances in self._widgets with
-        # information necessary to recreate widgets:
-        # widget_classe, description, and value
+        # __getstate__ replaces instances in self._widgets with information
+        # necessary to recreate widgets, i.e. widget_class, description, and
+        # value
         state = self.__dict__.copy()
         state['_widgets'] = state['_widgets'].copy()
         for key, widget in state['_widgets'].items():
@@ -346,8 +351,9 @@ class InteractiveAttributes(persistent.Persistent):
 
     def __setstate__(self, state):
         """Restore state from the unpickled state values."""
-        # __setstate__ should refill self._widgets with the information stored
-        # in self._widgets. Compare with self.add() for necessary steps
+        # __setstate__ refills self._widgets with the information stored in
+        # self._widgets. Compare with the function self.add() for necessary
+        # steps.
         for key, widgetState in state['_widgets'].items():
             if len(widgetState) == 2:
                 value, description = widgetState
